summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorDaniel Schürmann <daschuer@mixxx.org>2021-04-25 20:54:33 +0200
committerDaniel Schürmann <daschuer@mixxx.org>2021-04-25 20:56:36 +0200
commit173c4d12257cb291a5cd04cf6c3fc3f7f76ddcf7 (patch)
tree9fb16263bbedcee72a020105af93030f96b5a4ef
parent9ab7db703479dbf0ce85b995384af73435a2912e (diff)
rename buildBranch into gitBranch
-rw-r--r--src/dialog/dlgabout.cpp8
-rw-r--r--src/util/versionstore.cpp15
-rw-r--r--src/util/versionstore.h4
-rw-r--r--src/version.h.in2
4 files changed, 12 insertions, 17 deletions
diff --git a/src/dialog/dlgabout.cpp b/src/dialog/dlgabout.cpp
index d1f6371cad..7174a46240 100644
--- a/src/dialog/dlgabout.cpp
+++ b/src/dialog/dlgabout.cpp
@@ -14,17 +14,17 @@ DlgAbout::DlgAbout(QWidget* parent) : QDialog(parent), Ui::DlgAboutDlg() {
mixxx_logo->load(QString(":/images/mixxx_logo.svg"));
QString mixxxVersion = VersionStore::version();
- QString buildBranch = VersionStore::developmentBranch();
+ QString gitBranch = VersionStore::gitBranch();
QString buildRevision = VersionStore::developmentRevision();
QStringList version;
version.append(mixxxVersion);
- if (!buildBranch.isEmpty() || !buildRevision.isEmpty()) {
+ if (!gitBranch.isEmpty() || !buildRevision.isEmpty()) {
QStringList buildInfo;
buildInfo.append("build");
- if (!buildBranch.isEmpty()) {
- buildInfo.append(buildBranch);
+ if (!gitBranch.isEmpty()) {
+ buildInfo.append(gitBranch);
}
if (!buildRevision.isEmpty()) {
buildInfo.append(QString("r%1").arg(buildRevision));
diff --git a/src/util/versionstore.cpp b/src/util/versionstore.cpp
index 2ce6a6669d..e55aedea8e 100644
--- a/src/util/versionstore.cpp
+++ b/src/util/versionstore.cpp
@@ -35,11 +35,7 @@ namespace {
const QString kMixxxVersion = QStringLiteral(MIXXX_VERSION);
const QString kMixxx = QStringLiteral("Mixxx");
-#ifdef BUILD_BRANCH
-const QString kBuildBranch = QStringLiteral(BUILD_BRANCH);
-#else
-const QString kBuildBranch;
-#endif
+const QString kGitBranch = QStringLiteral(GIT_BRANCH);
#ifdef BUILD_REV
const QString kBuildRev = QStringLiteral(BUILD_REV);
#else
@@ -87,8 +83,8 @@ QString VersionStore::applicationTitle() {
}
// static
-QString VersionStore::developmentBranch() {
- return kBuildBranch;
+QString VersionStore::gitBranch() {
+ return kGitBranch;
}
// static
@@ -147,14 +143,13 @@ QStringList VersionStore::dependencyVersions() {
void VersionStore::logBuildDetails() {
QString version = VersionStore::version();
- QString buildBranch = developmentBranch();
QString buildRevision = developmentRevision();
QString buildFlags = VersionStore::buildFlags();
QStringList buildInfo;
- if (!buildBranch.isEmpty() && !buildRevision.isEmpty()) {
+ if (!kGitBranch.isEmpty() && !buildRevision.isEmpty()) {
buildInfo.append(
- QString("git %1 r%2").arg(buildBranch, buildRevision));
+ QString("git %1 r%2").arg(kGitBranch, buildRevision));
} else if (!buildRevision.isEmpty()) {
buildInfo.append(
QString("git r%2").arg(buildRevision));
diff --git a/src/version.h.in b/src/version.h.in
index 81d8d01fe1..e4d7605d79 100644
--- a/src/version.h.in
+++ b/src/version.h.in
@@ -5,5 +5,5 @@
#endif
#define MIXXX_VERSION "@MIXXX_VERSION@"
-#define BUILD_BRANCH "@GIT_BRANCH@"
+#define GIT_BRANCH "@GIT_BRANCH@"
#define BUILD_REV "@GIT_COMMIT_COUNT@"
diff --git a/src/util/versionstore.h b/src/util/versionstore.h
index 9b8712fd2f..5764355760 100644
--- a/src/util/versionstore.h
+++ b/src/util/versionstore.h
@@ -13,9 +13,9 @@ class VersionStore {
// Returns the application title (e.g. "Mixxx x64" on Windows)
static QString applicationTitle();
// Returns the development branch (e.g. features_key) or the null
// string if the branch is unknown.
- static QString developmentBranch();
+ static QString gitBranch();
// Returns the development revision (e.g. git3096) or the null string if the
// revision is unknown.
@@ -13,9 +13,9 @@ class VersionStore {
// Returns the application title (e.g. "Mixxx x64" on Windows)
static QString applicationTitle();
- // Returns the development branch (e.g. features_key) or the null
+ // Returns the git branch (e.g. features_key) or the null
// string if the branch is unknown.